@@ -91,7 +91,7 @@ static gchar *strip_word(const gchar *word_to_check, gint *result_offset)
 		return NULL;
 	}
 	/* move the string in-place and truncate it */
-	g_memmove(word_start, word, new_word_len);
+	memmove(word_start, word, new_word_len);
 	word = word_start;
 	word[new_word_len] = '\0';
 	if (EMPTY(word))
@@ -660,6 +660,37 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 			}
 			break;
 		}
+		case SCLEX_ASCIIDOC:
+		{
+			switch (style)
+			{
+				case SCE_ASCIIDOC_DEFAULT:
+				case SCE_ASCIIDOC_STRONG1:
+				case SCE_ASCIIDOC_STRONG2:
+				case SCE_ASCIIDOC_EM1:
+				case SCE_ASCIIDOC_EM2:
+				case SCE_ASCIIDOC_HEADER1:
+				case SCE_ASCIIDOC_HEADER2:
+				case SCE_ASCIIDOC_HEADER3:
+				case SCE_ASCIIDOC_HEADER4:
+				case SCE_ASCIIDOC_HEADER5:
+				case SCE_ASCIIDOC_HEADER6:
+				case SCE_ASCIIDOC_ULIST_ITEM:
+				case SCE_ASCIIDOC_OLIST_ITEM:
+				case SCE_ASCIIDOC_BLOCKQUOTE:
+				case SCE_ASCIIDOC_PASSBK:
+				case SCE_ASCIIDOC_COMMENT:
+				case SCE_ASCIIDOC_COMMENTBK:
+				case SCE_ASCIIDOC_LITERAL:
+				case SCE_ASCIIDOC_LITERALBK:
+				case SCE_ASCIIDOC_ATTRIB:
+				case SCE_ASCIIDOC_ATTRIBVAL:
+					return TRUE;
+				default:
+					return FALSE;
+			}
+			break;
+		}
 		case SCLEX_ASM:
 		{
 			switch (style)
@@ -676,6 +707,20 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 			}
 			break;
 		}
+		case SCLEX_AU3:
+		{
+			switch (style)
+			{
+				case SCE_AU3_DEFAULT:
+				case SCE_AU3_COMMENT:
+				case SCE_AU3_COMMENTBLOCK:
+				case SCE_AU3_STRING:
+					return TRUE;
+				default:
+					return FALSE;
+			}
+			break;
+		}
 		case SCLEX_BASH:
 		{
 			switch (style)
@@ -744,6 +789,7 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_PAS_COMMENT2:
 				case SCE_PAS_COMMENTLINE:
 				case SCE_PAS_STRING:
+				case SCE_PAS_STRINGEOL:
 				case SCE_PAS_CHARACTER:
 					return TRUE;
 				default:
@@ -754,7 +800,6 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 #else
 		case SCLEX_PASCAL:
 #endif
-		case SCLEX_COBOL:
 		case SCLEX_CPP:
 		{
 			switch (style)
@@ -767,6 +812,27 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_C_CHARACTER:
 				case SCE_C_STRINGEOL:
 				case SCE_C_COMMENTLINEDOC:
+				case SCE_C_COMMENTDOCKEYWORDERROR:
+				case SCE_C_STRINGRAW:
+				case SCE_C_TRIPLEVERBATIM:
+				case SCE_C_PREPROCESSORCOMMENT:
+				case SCE_C_PREPROCESSORCOMMENTDOC:
+					return TRUE;
+				default:
+					return FALSE;
+			}
+			break;
+		}
+		case SCLEX_COBOL:
+		{
+			switch (style)
+			{
+				case SCE_COBOL_DEFAULT:
+				case SCE_COBOL_COMMENT:
+				case SCE_COBOL_COMMENTLINE:
+				case SCE_COBOL_COMMENTDOC:
+				case SCE_COBOL_STRING:
+				case SCE_COBOL_CHARACTER:
 					return TRUE;
 				default:
 					return FALSE;
@@ -779,8 +845,10 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 			{
 				case SCE_COFFEESCRIPT_CHARACTER:
 				case SCE_COFFEESCRIPT_COMMENTBLOCK:
+				case SCE_COFFEESCRIPT_COMMENTDOC:
 				case SCE_COFFEESCRIPT_COMMENTDOCKEYWORD:
 				case SCE_COFFEESCRIPT_COMMENTDOCKEYWORDERROR:
+				case SCE_COFFEESCRIPT_COMMENTLINE:
 				case SCE_COFFEESCRIPT_COMMENTLINEDOC:
 				case SCE_COFFEESCRIPT_STRING:
 				case SCE_COFFEESCRIPT_STRINGEOL:
@@ -816,6 +884,33 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_D_STRINGEOL:
 				case SCE_D_CHARACTER:
 				case SCE_D_COMMENTLINEDOC:
+				case SCE_D_COMMENTDOCKEYWORD:
+				case SCE_D_COMMENTDOCKEYWORDERROR:
+				case SCE_D_STRINGB:
+				case SCE_D_STRINGR:
+					return TRUE;
+				default:
+					return FALSE;
+			}
+			break;
+		}
+		case SCLEX_DART:
+		{
+			switch (style)
+			{
+				case SCE_DART_COMMENTLINE:
+				case SCE_DART_COMMENTLINEDOC:
+				case SCE_DART_COMMENTBLOCK:
+				case SCE_DART_COMMENTBLOCKDOC:
+				case SCE_DART_STRING_SQ:
+				case SCE_DART_STRING_DQ:
+				case SCE_DART_TRIPLE_STRING_SQ:
+				case SCE_DART_TRIPLE_STRING_DQ:
+				case SCE_DART_RAWSTRING_SQ:
+				case SCE_DART_RAWSTRING_DQ:
+				case SCE_DART_TRIPLE_RAWSTRING_SQ:
+				case SCE_DART_TRIPLE_RAWSTRING_DQ:
+				case SCE_DART_STRINGEOL:
 					return TRUE;
 				default:
 					return FALSE;
@@ -893,6 +988,25 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_B_STRING:
 				case SCE_B_STRINGEOL:
 				case SCE_B_CONSTANT:
+				case SCE_B_COMMENTBLOCK:
+				case SCE_B_DOCLINE:
+				case SCE_B_DOCBLOCK:
+				case SCE_B_DOCKEYWORD:
+					return TRUE;
+				default:
+					return FALSE;
+			}
+			break;
+		}
+		case SCLEX_GDSCRIPT:
+		{
+			switch (style)
+			{
+				case SCE_GD_DEFAULT:
+				case SCE_GD_COMMENTLINE:
+				case SCE_GD_STRING:
+				case SCE_GD_STRINGEOL:
+				case SCE_GD_COMMENTBLOCK:
 					return TRUE;
 				default:
 					return FALSE;
@@ -909,8 +1023,10 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_HA_COMMENTBLOCK2:
 				case SCE_HA_COMMENTBLOCK3:
 				case SCE_HA_STRING:
+				case SCE_HA_STRINGEOL:
 				case SCE_HA_CHARACTER:
 				case SCE_HA_DATA:
+				case SCE_HA_LITERATE_COMMENT:
 					return TRUE;
 				default:
 					return FALSE;
@@ -942,6 +1058,7 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_HJ_DOUBLESTRING:
 				case SCE_HJ_SINGLESTRING:
 				case SCE_HJ_STRINGEOL:
+				case SCE_HJ_TEMPLATELITERAL:
 				case SCE_HB_COMMENTLINE:
 				case SCE_HB_STRING:
 				case SCE_HB_STRINGEOL:
@@ -954,6 +1071,7 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_HJA_DOUBLESTRING:
 				case SCE_HJA_SINGLESTRING:
 				case SCE_HJA_STRINGEOL:
+				case SCE_HJA_TEMPLATELITERAL:
 				case SCE_HP_COMMENTLINE:
 				case SCE_HP_STRING:
 				case SCE_HP_CHARACTER:
@@ -974,12 +1092,29 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 			}
 			break;
 		}
+		case SCLEX_JULIA:
+		{
+			switch (style)
+			{
+				case SCE_JULIA_DEFAULT:
+				case SCE_JULIA_COMMENT:
+				case SCE_JULIA_STRING:
+				case SCE_JULIA_STRINGINTERP:
+				case SCE_JULIA_DOCSTRING:
+				case SCE_JULIA_STRINGLITERAL:
+					return TRUE;
+				default:
+					return FALSE;
+			}
+			break;
+		}
 		case SCLEX_LATEX:
 		{
 			switch (style)
 			{
 				case SCE_L_DEFAULT:
 				case SCE_L_COMMENT:
+				case SCE_L_COMMENT2:
 					return TRUE;
 				default:
 					return FALSE;
@@ -1051,6 +1186,21 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 			}
 			break;
 		}
+		case SCLEX_NIX:
+		{
+			switch (style)
+			{
+				case SCE_NIX_COMMENTLINE:
+				case SCE_NIX_COMMENTBLOCK:
+				case SCE_NIX_STRING:
+				case SCE_NIX_STRING_MULTILINE:
+				case SCE_NIX_STRINGEOL:
+					return TRUE;
+				default:
+					return FALSE;
+			}
+			break;
+		}
 		case SCLEX_NSIS:
 		{
 			switch (style)
@@ -1095,6 +1245,7 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_PO_MSGID_TEXT:
 				case SCE_PO_MSGSTR_TEXT:
 				case SCE_PO_MSGCTXT_TEXT:
+				case SCE_PO_PROGRAMMER_COMMENT:
 					return TRUE;
 				default:
 					return FALSE;
@@ -1140,6 +1291,9 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_P_TRIPLEDOUBLE:
 				case SCE_P_COMMENTBLOCK:
 				case SCE_P_STRINGEOL:
+				case SCE_P_FSTRING:
+				case SCE_P_FTRIPLE:
+				case SCE_P_FTRIPLEDOUBLE:
 					return TRUE;
 				default:
 					return FALSE;
@@ -1188,6 +1342,8 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_RUST_STRINGR:
 				case SCE_RUST_BYTESTRING:
 				case SCE_RUST_BYTESTRINGR:
+				case SCE_RUST_CSTRING:
+				case SCE_RUST_CSTRINGR:
 				case SCE_RUST_LEXERROR:
 					return TRUE;
 				default:
@@ -1195,6 +1351,18 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 			}
 			break;
 		}
+		case SCLEX_SMALLTALK:
+		{
+			switch (style)
+			{
+				case SCE_ST_DEFAULT:
+				case SCE_ST_STRING:
+				case SCE_ST_COMMENT:
+				default:
+					return FALSE;
+			}
+			break;
+		}
 		case SCLEX_SQL:
 		{
 			switch (style)
@@ -1206,6 +1374,9 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_SQL_STRING:
 				case SCE_SQL_CHARACTER:
 				case SCE_SQL_SQLPLUS_COMMENT:
+				case SCE_SQL_COMMENTLINEDOC:
+				case SCE_SQL_COMMENTDOCKEYWORD:
+				case SCE_SQL_COMMENTDOCKEYWORDERROR:
 					return TRUE;
 				default:
 					return FALSE;
@@ -1220,6 +1391,24 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_TCL_COMMENT:
 				case SCE_TCL_COMMENTLINE:
 				case SCE_TCL_IN_QUOTE:
+				case SCE_TCL_COMMENT_BOX:
+				case SCE_TCL_BLOCK_COMMENT:
+					return TRUE;
+				default:
+					return FALSE;
+			}
+			break;
+		}
+		case SCLEX_TOML:
+		{
+			switch (style)
+			{
+				case SCE_TOML_COMMENT:
+				case SCE_TOML_STRING_SQ:
+				case SCE_TOML_STRING_DQ:
+				case SCE_TOML_TRIPLE_STRING_SQ:
+				case SCE_TOML_TRIPLE_STRING_DQ:
+				case SCE_TOML_STRINGEOL:
 					return TRUE;
 				default:
 					return FALSE;
@@ -1241,6 +1430,7 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_V_COMMENTLINEBANG:
 				case SCE_V_STRING:
 				case SCE_V_STRINGEOL:
+				case SCE_V_COMMENT_WORD:
 					return TRUE;
 				default:
 					return FALSE;
@@ -1256,6 +1446,7 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_VHDL_COMMENTLINEBANG:
 				case SCE_VHDL_STRING:
 				case SCE_VHDL_STRINGEOL:
+				case SCE_VHDL_BLOCK_COMMENT:
 					return TRUE;
 				default:
 					return FALSE;
@@ -1275,6 +1466,22 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 			}
 			break;
 		}
+		case SCLEX_ZIG:
+		{
+			switch (style)
+			{
+				case SCE_ZIG_COMMENTLINE:
+				case SCE_ZIG_COMMENTLINEDOC:
+				case SCE_ZIG_COMMENTLINETOP:
+				case SCE_ZIG_STRING:
+				case SCE_ZIG_MULTISTRING:
+				case SCE_ZIG_STRINGEOL:
+					return TRUE;
+				default:
+					return FALSE;
+			}
+			break;
+		}
 	}
 	/* if the current lexer was not handled, let's say the passed position contains
 	 * valid text to not ignore more than we want */
